@@ -63,6 +63,7 @@
 #include "dialogs/finddialog.h"
 #include "dialogs/focusdialog.h"
 #include "dialogs/fovdialog.h"
+#include "printing/printingwizard.h"
 #include "kswizard.h"
 #include "tools/lcgenerator.h"
 #include "tools/astrocalc.h"
@@ -92,6 +93,7 @@
 #include "skycomponents/solarsystemcomposite.h"
 #include "skycomponents/cometscomponent.h"
 #include "skycomponents/asteroidscomponent.h"
+#include "skycomponents/supernovaecomponent.h"
 
 #ifdef HAVE_CFITSIO_H
 #include "fitsviewer/fitsviewer.h"
@@ -172,6 +174,11 @@ void KStars::slotViewToolBar() {
         if ( kcd ) {
             opssatellites->kcfg_ShowSatellites->setChecked( a->isChecked() );
         }
+    } else if ( a == actionCollection()->action( "show_supernovae" ) ) {
+        Options::setShowSupernovae( a->isChecked() );
+//         if ( kcd ) {
+//             opsupernovae->kcfg_ShowSupernovae->setChecked ( a->isChecked() ) ;
+//         }
     }
 
     // update time for all objects because they might be not initialized
@@ -519,6 +526,11 @@ void KStars::slotOpenFITS()
 void KStars::slotExportImage() {
     KUrl fileURL = KFileDialog::getSaveUrl( QDir::homePath(), "image/png image/jpeg image/gif image/x-portable-pixmap image/bmp image/svg+xml" );
 
+    //User cancelled file selection dialog - abort image export
+    if ( fileURL.isEmpty() ) {
+        return;
+    }
+
     //Warn user if file exists!
     if (QFile::exists(fileURL.path()))
     {
@@ -674,6 +686,15 @@ void KStars::slotPrint() {
     printImage( true, switchColors );
 }
 
+void KStars::slotPrintingWizard() {
+    if(printingWizard) {
+        delete printingWizard;
+    }
+
+    printingWizard = new PrintingWizard(this);
+    printingWizard->show();
+}
+
 void KStars::slotToggleTimer() {
     if ( data()->clock()->isActive() ) {
         data()->clock()->stop();
@@ -685,6 +706,9 @@ void KStars::slotToggleTimer() {
         if ( data()->clock()->isManualMode() )
             map()->forceUpdate();
     }
+    
+    // Update clock state in options
+    Options::setRunClock( data()->clock()->isActive() );
 }
 
 void KStars::slotStepForward() {
@@ -1054,3 +1078,8 @@ void KStars::slotUpdateComets() {
 void KStars::slotUpdateAsteroids() {
     data()->skyComposite()->solarSystemComposite()->asteroidsComponent()->updateDataFile();
 }
+
+void KStars::slotUpdateSupernovae()
+{
+    data()->skyComposite()->supernovaeComponent()->updateDataFile();
+}
