@@ -210,6 +210,10 @@ void DeepStarComponent::draw( SkyPainter *skyp ) {
 
     magLim = maglim;
 
+    // If we are to hide the fainter stars (eg: while slewing), we set the magnitude limit to hideStarsMag.
+    if( hideFaintStars && maglim > hideStarsMag )
+        maglim = hideStarsMag;
+
     StarBlockFactory *m_StarBlockFactory = StarBlockFactory::Instance();
     //    m_StarBlockFactory->drawID = m_skyMesh->drawID();
     //    kDebug() << "Mesh size = " << m_skyMesh->size() << "; drawID = " << m_skyMesh->drawID();
@@ -264,6 +268,7 @@ void DeepStarComponent::draw( SkyPainter *skyp ) {
 
         //        kDebug() << "Drawing SBL for trixel " << currentRegion << ", SBL has " 
         //                 <<  m_starBlockList[ currentRegion ]->getBlockCount() << " blocks" << endl;
+
         for( int i = 0; i < m_starBlockList.at( currentRegion )->getBlockCount(); ++i ) {
             StarBlock *block = m_starBlockList.at( currentRegion )->block( i );
             //            kDebug() << "---> Drawing stars from block " << i << " of trixel " << 
@@ -276,11 +281,11 @@ void DeepStarComponent::draw( SkyPainter *skyp ) {
                 //<< ", and indexStar says he's from " << m_skyMesh->indexStar( curStar );
 
                 if ( curStar->updateID != updateID )
-                    curStar->JITupdate( data );
+                    curStar->JITupdate();
 
                 float mag = curStar->mag();
 
-                if ( mag > maglim || ( hideFaintStars && mag > hideStarsMag ) )
+                if ( mag > maglim )
                     break;
 
                 if( skyp->drawPointSource(curStar, mag, curStar->spchar() ) )
