@@ -723,9 +723,8 @@ int Satellite::sgp4( double tsince )
         const double g52   = 1.0508330;
         const double g54   = 4.4108898;
         const double rptim = 4.37526908801129966e-3; // this equates to 7.29211514668855e-5 rad/sec
-        const double stepp =    720.0;
-        const double stepn =   -720.0;
-        const double step2 = 259200.0;
+        const double step  =    720.0;
+        const double step2 = step * step / 2;
 
         // Calculate deep space resonance effects
         dndt   = 0.0;
@@ -747,9 +746,9 @@ int Satellite::sgp4( double tsince )
             }
             
             if ( tsince > 0.0 )
-                delt = stepp;
+                delt =  step;
             else
-                delt = stepn;
+                delt = -step;
 
             iretn = 381; // added for do loop
 
@@ -783,7 +782,7 @@ int Satellite::sgp4( double tsince )
                     xnddt = xnddt * xldot;
                 }
 
-                if ( fabs( tsince - atime ) >= stepp ) {
+                if ( fabs( tsince - atime ) >= step ) {
                     iretn = 381;
                 } else {
                     ft    = tsince - atime;
